translate.filters

Package translate :: Package filters |
[hide private]
[frames] | no frames]

# Package filters

source code

Filters that can be used on translations...

Submodules | [hide private]
translate.filters.autocorrect: A set of autocorrect functions that fix common punctuation and space problems automatically translate.filters.checks: This is a set of validation checks that can be performed on translation units. translate.filters.decoration: functions to get decorative/informative text out of strings... translate.filters.helpers: a set of helper functions for filters... translate.filters.pofilter: Perform quality checks on Gettext PO, XLIFF and TMX localization files translate.filters.prefilters: This is a set of string filters that strings can be passed through before certain tests. translate.filters.spelling: An API to provide spell checking for use in checks or elsewhere.

Variables | [hide private]
| __package__ = `None` hash(x)